# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.backup_info import BackupInfo


class TestBackupInfo(unittest.TestCase):
    """BackupInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BackupInfo:
        """Test BackupInfo
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `BackupInfo`
        """
        model = BackupInfo()
        if include_optional:
            return BackupInfo(
                status = cybee_sdk.api.models.backup_status.BackupStatus(
                    seconds_elapsed = 56, 
                    seconds_remaining = 56, 
                    percent_done = 1.337, 
                    total_files = 56, 
                    files_done = 56, 
                    total_bytes = 56, 
                    bytes_done = 56, 
                    error_count = 56, 
                    current_files = [
                        ''
                        ], ),
                restic_error = cybee_sdk.api.models.backup_error.BackupError(
                    error = '', 
                    during = '', 
                    item = '', ),
                restic_fatal_error = cybee_sdk.api.models.backup_fatal_error.BackupFatalError(
                    code = 56, 
                    message = '', ),
                verbose_status = cybee_sdk.api.models.backup_verbose_status.BackupVerboseStatus(
                    action = '', 
                    item = '', 
                    duration = 1.337, 
                    data_size = 56, 
                    data_size_in_repo = 56, 
                    metadata_size = 56, 
                    metadata_size_in_repo = 56, 
                    total_files = 56, ),
                summary = cybee_sdk.api.models.backup_summary.BackupSummary(
                    files_new = 0.0, 
                    files_changed = 0.0, 
                    files_unmodified = 0.0, 
                    dirs_new = 0.0, 
                    dirs_changed = 0.0, 
                    dirs_unmodified = 0.0, 
                    data_blobs = 0.0, 
                    tree_blobs = 0.0, 
                    data_added = 0.0, 
                    data_added_packed = 0.0, 
                    total_files_processed = 0.0, 
                    total_bytes_processed = 0.0, 
                    total_duration = 1.337, 
                    snapshot_id = '', ),
                unknown = '',
                other_error = '',
                backup_ended = cybee_sdk.api.models.process_ended.ProcessEnded(),
                backup_fully_finished = cybee_sdk.api.models.operation_fully_finished.OperationFullyFinished(),
                timestamp = '',
                backup_paths = [
                    ''
                    ]
            )
        else:
            return BackupInfo(
                timestamp = '',
        )
        """

    def testBackupInfo(self):
        """Test BackupInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.identity_api import IdentityApi


class TestIdentityApi(unittest.TestCase):
    """IdentityApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IdentityApi()

    def tearDown(self) -> None:
        pass

    def test_create_api_key_identity_keys_post(self) -> None:
        """Test case for create_api_key_identity_keys_post

        Create Api Key
        """
        pass

    def test_list_all_api_keys_identity_keys_get(self) -> None:
        """Test case for list_all_api_keys_identity_keys_get

        List All Api Keys
        """
        pass

    def test_list_all_organization_identity_organization_get(self) -> None:
        """Test case for list_all_organization_identity_organization_get

        List All Organization
        """
        pass

    def test_revoke_api_key_identity_keys_key_id_delete(self) -> None:
        """Test case for revoke_api_key_identity_keys_key_id_delete

        Revoke Api Key
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class BackupSummary(BaseModel):
    """
    BackupSummary
    """  # noqa: E501

    files_new: Annotated[int, Field(strict=True, ge=0)]
    files_changed: Optional[Annotated[int, Field(strict=True, ge=0)]] = None
    files_unmodified: Optional[Annotated[int, Field(strict=True, ge=0)]] = None
    dirs_new: Optional[Annotated[int, Field(strict=True, ge=0)]] = None
    dirs_changed: Optional[Annotated[int, Field(strict=True, ge=0)]] = None
    dirs_unmodified: Optional[Annotated[int, Field(strict=True, ge=0)]] = None
    data_blobs: Optional[Annotated[int, Field(strict=True, ge=0)]] = None
    tree_blobs: Annotated[int, Field(strict=True, ge=0)]
    data_added: Annotated[int, Field(strict=True, ge=0)]
    data_added_packed: Optional[Annotated[int, Field(strict=True, ge=0)]] = None
    total_files_processed: Annotated[int, Field(strict=True, ge=0)]
    total_bytes_processed: Annotated[int, Field(strict=True, ge=0)]
    total_duration: Union[StrictFloat, StrictInt]
    snapshot_id: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = [
        "files_new",
        "files_changed",
        "files_unmodified",
        "dirs_new",
        "dirs_changed",
        "dirs_unmodified",
        "data_blobs",
        "tree_blobs",
        "data_added",
        "data_added_packed",
        "total_files_processed",
        "total_bytes_processed",
        "total_duration",
        "snapshot_id",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BackupSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if files_changed (nullable) is None
        # and model_fields_set contains the field
        if self.files_changed is None and "files_changed" in self.model_fields_set:
            _dict["files_changed"] = None

        # set to None if files_unmodified (nullable) is None
        # and model_fields_set contains the field
        if self.files_unmodified is None and "files_unmodified" in self.model_fields_set:
            _dict["files_unmodified"] = None

        # set to None if dirs_new (nullable) is None
        # and model_fields_set contains the field
        if self.dirs_new is None and "dirs_new" in self.model_fields_set:
            _dict["dirs_new"] = None

        # set to None if dirs_changed (nullable) is None
        # and model_fields_set contains the field
        if self.dirs_changed is None and "dirs_changed" in self.model_fields_set:
            _dict["dirs_changed"] = None

        # set to None if dirs_unmodified (nullable) is None
        # and model_fields_set contains the field
        if self.dirs_unmodified is None and "dirs_unmodified" in self.model_fields_set:
            _dict["dirs_unmodified"] = None

        # set to None if data_blobs (nullable) is None
        # and model_fields_set contains the field
        if self.data_blobs is None and "data_blobs" in self.model_fields_set:
            _dict["data_blobs"] = None

        # set to None if data_added_packed (nullable) is None
        # and model_fields_set contains the field
        if self.data_added_packed is None and "data_added_packed" in self.model_fields_set:
            _dict["data_added_packed"] = None

        # set to None if snapshot_id (nullable) is None
        # and model_fields_set contains the field
        if self.snapshot_id is None and "snapshot_id" in self.model_fields_set:
            _dict["snapshot_id"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BackupSummary from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "files_new": obj.get("files_new"),
                "files_changed": obj.get("files_changed"),
                "files_unmodified": obj.get("files_unmodified"),
                "dirs_new": obj.get("dirs_new"),
                "dirs_changed": obj.get("dirs_changed"),
                "dirs_unmodified": obj.get("dirs_unmodified"),
                "data_blobs": obj.get("data_blobs"),
                "tree_blobs": obj.get("tree_blobs"),
                "data_added": obj.get("data_added"),
                "data_added_packed": obj.get("data_added_packed"),
                "total_files_processed": obj.get("total_files_processed"),
                "total_bytes_processed": obj.get("total_bytes_processed"),
                "total_duration": obj.get("total_duration"),
                "snapshot_id": obj.get("snapshot_id"),
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.storage_repository_api import StorageRepositoryApi


class TestStorageRepositoryApi(unittest.TestCase):
    """StorageRepositoryApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StorageRepositoryApi()

    def tearDown(self) -> None:
        pass

    def test_create_repository_storage_repository_post(self) -> None:
        """Test case for create_repository_storage_repository_post

        Create Repository
        """
        pass

    def test_delete_repository_storage_repository_repository_id_delete(self) -> None:
        """Test case for delete_repository_storage_repository_repository_id_delete

        Delete Repository
        """
        pass

    def test_execute_repository_maintenance_storage_repository_repository_id_maintenance_maintenance_type_execute_post(
        self,
    ) -> None:
        """Test case for execute_repository_maintenance_storage_repository_repository_id_maintenance_maintenance_type_execute_post

        Execute Repository Maintenance
        """
        pass

    def test_get_repository_maintenance_storage_repository_repository_id_maintenance_get(self) -> None:
        """Test case for get_repository_maintenance_storage_repository_repository_id_maintenance_get

        Get Repository Maintenance
        """
        pass

    def test_get_repository_storage_repository_repository_id_get(self) -> None:
        """Test case for get_repository_storage_repository_repository_id_get

        Get Repository
        """
        pass

    def test_list_repository_checks_storage_repository_check_history_get(self) -> None:
        """Test case for list_repository_checks_storage_repository_check_history_get

        List Repository Checks
        """
        pass

    def test_list_repository_prunes_storage_repository_prune_history_get(self) -> None:
        """Test case for list_repository_prunes_storage_repository_prune_history_get

        List Repository Prunes
        """
        pass

    def test_list_repository_stats_storage_repository_stats_get(self) -> None:
        """Test case for list_repository_stats_storage_repository_stats_get

        List Repository Stats
        """
        pass

    def test_list_repository_storage_repository_get(self) -> None:
        """Test case for list_repository_storage_repository_get

        List Repository
        """
        pass

    def test_set_repository_maintenance_storage_repository_repository_id_maintenance_maintenance_type_post(
        self,
    ) -> None:
        """Test case for set_repository_maintenance_storage_repository_repository_id_maintenance_maintenance_type_post

        Set Repository Maintenance
        """
        pass

    def test_unset_repository_maintenance_storage_repository_repository_id_maintenance_maintenance_type_delete(
        self,
    ) -> None:
        """Test case for unset_repository_maintenance_storage_repository_repository_id_maintenance_maintenance_type_delete

        Unset Repository Maintenance
        """
        pass

    def test_update_repository_storage_repository_repository_id_patch(self) -> None:
        """Test case for update_repository_storage_repository_repository_id_patch

        Update Repository
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.scheduling import Scheduling


class TestScheduling(unittest.TestCase):
    """Scheduling unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Scheduling:
        """Test Scheduling
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Scheduling`
        """
        model = Scheduling()
        if include_optional:
            return Scheduling(
                id = '',
                timestamps = cybee_sdk.api.models.time_stamps.TimeStamps(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                enabled = True,
                cron_calendar = cybee_sdk.api.models.cron_calendar.CronCalendar(
                    minute = null, 
                    hour = null, 
                    day_of_month = null, 
                    month_of_year = null, 
                    day_of_week = null, 
                    timezone = null, ),
                linked_plans = [
                    cybee_sdk.api.models.scheduling_linked_plans.SchedulingLinkedPlans(
                        id = '', 
                        type = null, )
                    ]
            )
        else:
            return Scheduling(
                id = '',
                timestamps = cybee_sdk.api.models.time_stamps.TimeStamps(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                cron_calendar = cybee_sdk.api.models.cron_calendar.CronCalendar(
                    minute = null, 
                    hour = null, 
                    day_of_month = null, 
                    month_of_year = null, 
                    day_of_week = null, 
                    timezone = null, ),
        )
        """

    def testScheduling(self):
        """Test Scheduling"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class Os(BaseModel):
    """
    Os
    """  # noqa: E501

    name: Optional[StrictStr] = None
    kernel_version: Optional[StrictStr] = None
    os_version: Optional[StrictStr] = None
    long_os_version: Optional[StrictStr] = None
    distribution_id: StrictStr
    host_name: Optional[StrictStr] = None
    license_info: Optional[StrictStr] = None
    domain_name: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = [
        "name",
        "kernel_version",
        "os_version",
        "long_os_version",
        "distribution_id",
        "host_name",
        "license_info",
        "domain_name",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Os from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict["name"] = None

        # set to None if kernel_version (nullable) is None
        # and model_fields_set contains the field
        if self.kernel_version is None and "kernel_version" in self.model_fields_set:
            _dict["kernel_version"] = None

        # set to None if os_version (nullable) is None
        # and model_fields_set contains the field
        if self.os_version is None and "os_version" in self.model_fields_set:
            _dict["os_version"] = None

        # set to None if long_os_version (nullable) is None
        # and model_fields_set contains the field
        if self.long_os_version is None and "long_os_version" in self.model_fields_set:
            _dict["long_os_version"] = None

        # set to None if host_name (nullable) is None
        # and model_fields_set contains the field
        if self.host_name is None and "host_name" in self.model_fields_set:
            _dict["host_name"] = None

        # set to None if license_info (nullable) is None
        # and model_fields_set contains the field
        if self.license_info is None and "license_info" in self.model_fields_set:
            _dict["license_info"] = None

        # set to None if domain_name (nullable) is None
        # and model_fields_set contains the field
        if self.domain_name is None and "domain_name" in self.model_fields_set:
            _dict["domain_name"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Os from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "name": obj.get("name"),
                "kernel_version": obj.get("kernel_version"),
                "os_version": obj.get("os_version"),
                "long_os_version": obj.get("long_os_version"),
                "distribution_id": obj.get("distribution_id"),
                "host_name": obj.get("host_name"),
                "license_info": obj.get("license_info"),
                "domain_name": obj.get("domain_name"),
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from cybee_sdk.api.models.cron_calendar import CronCalendar
from cybee_sdk.api.models.scheduling_linked_plans import SchedulingLinkedPlans
from cybee_sdk.api.models.time_stamps import TimeStamps
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class Scheduling(BaseModel):
    """
    Scheduling
    """  # noqa: E501

    id: UUID
    timestamps: TimeStamps
    enabled: Optional[StrictBool] = False
    cron_calendar: CronCalendar
    linked_plans: Optional[List[SchedulingLinkedPlans]] = None
    __properties: ClassVar[List[str]] = ["id", "timestamps", "enabled", "cron_calendar", "linked_plans"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Scheduling from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict["timestamps"] = self.timestamps.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cron_calendar
        if self.cron_calendar:
            _dict["cron_calendar"] = self.cron_calendar.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in linked_plans (list)
        _items = []
        if self.linked_plans:
            for _item_linked_plans in self.linked_plans:
                if _item_linked_plans:
                    _items.append(_item_linked_plans.to_dict())
            _dict["linked_plans"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Scheduling from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "timestamps": TimeStamps.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None,
                "enabled": obj.get("enabled") if obj.get("enabled") is not None else False,
                "cron_calendar": CronCalendar.from_dict(obj["cron_calendar"])
                if obj.get("cron_calendar") is not None
                else None,
                "linked_plans": [SchedulingLinkedPlans.from_dict(_item) for _item in obj["linked_plans"]]
                if obj.get("linked_plans") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class RetentionSettings(BaseModel):
    """
    RetentionSettings
    """  # noqa: E501

    keep_last: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_hourly: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_daily: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_weekly: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_monthly: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_yearly: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_within_as_secs: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_within_hourly_as_secs: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_within_daily_as_secs: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_within_weekly_as_secs: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_within_monthly_as_secs: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_within_yearly_as_secs: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    __properties: ClassVar[List[str]] = [
        "keep_last",
        "keep_hourly",
        "keep_daily",
        "keep_weekly",
        "keep_monthly",
        "keep_yearly",
        "keep_within_as_secs",
        "keep_within_hourly_as_secs",
        "keep_within_daily_as_secs",
        "keep_within_weekly_as_secs",
        "keep_within_monthly_as_secs",
        "keep_within_yearly_as_secs",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RetentionSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if keep_last (nullable) is None
        # and model_fields_set contains the field
        if self.keep_last is None and "keep_last" in self.model_fields_set:
            _dict["keep_last"] = None

        # set to None if keep_hourly (nullable) is None
        # and model_fields_set contains the field
        if self.keep_hourly is None and "keep_hourly" in self.model_fields_set:
            _dict["keep_hourly"] = None

        # set to None if keep_daily (nullable) is None
        # and model_fields_set contains the field
        if self.keep_daily is None and "keep_daily" in self.model_fields_set:
            _dict["keep_daily"] = None

        # set to None if keep_weekly (nullable) is None
        # and model_fields_set contains the field
        if self.keep_weekly is None and "keep_weekly" in self.model_fields_set:
            _dict["keep_weekly"] = None

        # set to None if keep_monthly (nullable) is None
        # and model_fields_set contains the field
        if self.keep_monthly is None and "keep_monthly" in self.model_fields_set:
            _dict["keep_monthly"] = None

        # set to None if keep_yearly (nullable) is None
        # and model_fields_set contains the field
        if self.keep_yearly is None and "keep_yearly" in self.model_fields_set:
            _dict["keep_yearly"] = None

        # set to None if keep_within_as_secs (nullable) is None
        # and model_fields_set contains the field
        if self.keep_within_as_secs is None and "keep_within_as_secs" in self.model_fields_set:
            _dict["keep_within_as_secs"] = None

        # set to None if keep_within_hourly_as_secs (nullable) is None
        # and model_fields_set contains the field
        if self.keep_within_hourly_as_secs is None and "keep_within_hourly_as_secs" in self.model_fields_set:
            _dict["keep_within_hourly_as_secs"] = None

        # set to None if keep_within_daily_as_secs (nullable) is None
        # and model_fields_set contains the field
        if self.keep_within_daily_as_secs is None and "keep_within_daily_as_secs" in self.model_fields_set:
            _dict["keep_within_daily_as_secs"] = None

        # set to None if keep_within_weekly_as_secs (nullable) is None
        # and model_fields_set contains the field
        if self.keep_within_weekly_as_secs is None and "keep_within_weekly_as_secs" in self.model_fields_set:
            _dict["keep_within_weekly_as_secs"] = None

        # set to None if keep_within_monthly_as_secs (nullable) is None
        # and model_fields_set contains the field
        if self.keep_within_monthly_as_secs is None and "keep_within_monthly_as_secs" in self.model_fields_set:
            _dict["keep_within_monthly_as_secs"] = None

        # set to None if keep_within_yearly_as_secs (nullable) is None
        # and model_fields_set contains the field
        if self.keep_within_yearly_as_secs is None and "keep_within_yearly_as_secs" in self.model_fields_set:
            _dict["keep_within_yearly_as_secs"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RetentionSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "keep_last": obj.get("keep_last"),
                "keep_hourly": obj.get("keep_hourly"),
                "keep_daily": obj.get("keep_daily"),
                "keep_weekly": obj.get("keep_weekly"),
                "keep_monthly": obj.get("keep_monthly"),
                "keep_yearly": obj.get("keep_yearly"),
                "keep_within_as_secs": obj.get("keep_within_as_secs"),
                "keep_within_hourly_as_secs": obj.get("keep_within_hourly_as_secs"),
                "keep_within_daily_as_secs": obj.get("keep_within_daily_as_secs"),
                "keep_within_weekly_as_secs": obj.get("keep_within_weekly_as_secs"),
                "keep_within_monthly_as_secs": obj.get("keep_within_monthly_as_secs"),
                "keep_within_yearly_as_secs": obj.get("keep_within_yearly_as_secs"),
            }
        )
        return _obj
